@@ -42,6 +42,7 @@ class CommandItem:
     """
 
     def __init__(self, key: bytes, db: Database, item: Optional["CommandItem"] = None, default: Any = None) -> None:
+        self._expireat: Optional[int]
         if item is None:
             self._value = default
             self._expireat = None
@@ -68,7 +69,7 @@ class CommandItem:
         return self._expireat
 
     @expireat.setter
-    def expireat(self, value: int) -> None:
+    def expireat(self, value: Optional[int]) -> None:
         self._expireat = value
         self._expireat_modified = True
         self._modified = True  # Since redis 6.0.7
@@ -411,7 +412,7 @@ class Signature:
                         and type(item.value) is not type_.type_
                 ):
                     raise SimpleError(msgs.WRONGTYPE_MSG)
-                if (msgs.FLAG_NO_INITIATE not in self.flags
+                if (msgs.FLAG_DO_NOT_CREATE not in self.flags
                         and type_.type_ is not None
                         and item is None
                         and type_.type_ is not bytes):
